# This file has been generated


build_system = 'AppVeyor'
build_id = '32133748'
build_number = '645'
build_version = '1.0.645'
job_id = 'yvkae4u2e7lq5sjb'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/yvkae4u2e7lq5sjb'
